MAJOR = 0
MINOR = 1
PATCH = 0
SUFFIX = ""

NAME = "sqspy"

AUTHOR = MAINTAINER = {
    "name": "hjpotter92",
    "email": "hjpotter92+pypi@gmail.com",
}

AUTHORS = MAINTAINERS = (f"{AUTHOR.get('name')} <{AUTHOR.get('email')}>",)

__version__ = VERSION = f"{MAJOR}.{MINOR}.{PATCH}{SUFFIX}"
